---
title: <span class="badge object-type-scalar"></span> MessagesPerSecond
---
# <span class="badge object-type-scalar"></span> MessagesPerSecond

Throughput: messages/sec (mps)

## Definition

```python
# Throughput: messages/sec (mps)
MessagesPerSecond: typing.Literal["mps"] = "mps"
```
